﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using TFlex;
using TFlex.Model;
using TFlex.Model.Model2D;

namespace API_Initialization
{
    public partial class MainForm : Form
    {
        //Переменная документа
        public Document doc;
       
        //Инициализация T-FLEX CAD API и компонентов windows-формы
        public MainForm()
        {
            //Укажите Вашу версию T-FLEX CAD либо T-FLEX Viewer
            string version = "T-FLEX CAD 3D 11.0\\Rus";
            //string version = "T-FLEX Viewer 11.0\\Rus";

            //Метод определяющий директорию, в которую установлен T-FLEX CAD
            APILoader.Initialize(version);

            //Метод, инициализирующий API
            APILoader.InitializeTFlexCADAPI();

            //Инициализация компонентов windows-формы
            InitializeComponent();
        }

        //Открыть документ T-FLEX CAD
        private void OpenTFDoc_Click(object sender, EventArgs e)
        {
            //Показать диалог открытия документа T-FLEX CAD
            OpenFileDialog openFileDlg = new OpenFileDialog();
            openFileDlg.Title = "Open Document";
            openFileDlg.Filter = "T-FLEX CAD Document (*.grb)|*.grb";
            openFileDlg.FilterIndex = 1;
            if (openFileDlg.ShowDialog() == DialogResult.OK)
            {
                doc = TFlex.Application.OpenDocument(openFileDlg.FileName);

                //Отобразить документ T-FLEX CAD в элементе типа control1
                tfcontrol.Document = doc;

                //Показать построения (команда "Скрыть построения" в false)
                tfcontrol.HideConstructions = false;

            }
        }

        //Обработка двойного щелчка на злементе control1
        private void tfcontrol_MouseDblClick(object sender, TFlex.ControlEventArgs e)
        {
            try
            {
                //Получить координаты точки
                Point clickPoint = new Point(e.x, e.y);

                //Привести координаты точки к документу TFlex
                TFlex.Drawing.Point point = tfcontrol.Graphics.GetWCSPoint(clickPoint);

                if (doc != null)
                {
                    //Открыть блок изменений документа
                    doc.BeginChanges("");

                    //Создать свободный узел на поле документа T-FLEX CAD
                    FreeNode node = new FreeNode(doc, point.X, point.Y);

                    //Закрыть блок изменения документа
                    doc.EndChanges();

                    //Перерисовать документ
                    tfcontrol.Redraw();
                }
            }
            catch
            {

            }
        }

        //Создать новый документ
        private void NewTFDoc_Click(object sender, EventArgs e)
        {
            //Закрыть документ
            ClosingDocument();

            //Создать новый документ
            doc = TFlex.Application.NewDocument();

            //Отобразить документ T-FLEX CAD в элементе типа control1
            tfcontrol.Document = doc;

            //Показать построения (команда "Скрыть построения" в false)
            tfcontrol.HideConstructions = false;
        }

        //Закрытие программы
        private void MainForm_FormClosed(object sender, FormClosedEventArgs e)
        {
            //Закрыть документ
            ClosingDocument();

            //Деинициализация API
            APILoader.Terminate();
        }

        //Закрыть документ
        private void ClosingDocument()
        {
            if (doc != null)
            {
                //Сохранить документ
                //document.Save();

                //Закрыть документ
                doc.Close();

                //Обнулить ссылку на документ
                doc = null;
            }
        }
    }
}